==> seleniumbase-1.47.0.tar.gz: seleniumbase-1.47.0/help_docs/locale_codes.md <==
<h2><img src="https://seleniumbase.io/img/sb_icon.png" title="SeleniumBase" width="24" /> Language Locale Codes</h2>

You can specify a Language Locale Code to customize web pages on supported websites. With SeleniumBase you can change the web browser's Locale on the command line by adding:

```bash
--locale=CODE  # Example: --locale=ru
```

<h3><img src="https://seleniumbase.io/img/sb_icon.png" title="SeleniumBase" width="24" /> List of Language Locale Codes:</h3>

<table>
    <thead><tr><th>Language</th><th>Code</th></tr></thead>
    <tbody class="list">
      <tr><td>Afrikaans</td><td><code translate="no" dir="ltr">af</code></td></tr>
      <tr><td>Amharic</td><td><code translate="no" dir="ltr">am</code></td></tr>
      <tr><td>Arabic</td><td><code translate="no" dir="ltr">ar</code></td></tr>
      <tr><td>Arabic (Egypt)</td><td><code translate="no" dir="ltr">ar_<wbr>eg</code></td></tr>
      <tr><td>Arabic (Saudi Arabia)</td><td><code translate="no" dir="ltr">ar_<wbr>sa</code></td></tr>
      <tr><td>Basque</td><td><code translate="no" dir="ltr">eu</code></td></tr>
      <tr><td>Belarusian</td><td><code translate="no" dir="ltr">be</code></td></tr>
      <tr><td>Bengali</td><td><code translate="no" dir="ltr">bn</code></td></tr>
      <tr><td>Bulgarian</td><td><code translate="no" dir="ltr">bg</code></td></tr>
      <tr><td>Catalan</td><td><code translate="no" dir="ltr">ca</code></td></tr>
      <tr><td>Chinese</td><td><code translate="no" dir="ltr">zh</code></td></tr>
      <tr><td>Chinese (China Mainland)</td><td><code translate="no" dir="ltr">zh_<wbr>cn</code></td></tr>
      <tr><td>Chinese (Hong Kong)</td><td><code translate="no" dir="ltr">zh_<wbr>hk</code></td></tr>
      <tr><td>Chinese (Taiwan)</td><td><code translate="no" dir="ltr">zh_<wbr>tw</code></td></tr>
      <tr><td>Croatian</td><td><code translate="no" dir="ltr">hr</code></td></tr>
      <tr><td>Czech</td><td><code translate="no" dir="ltr">cs</code></td></tr>
      <tr><td>Danish</td><td><code translate="no" dir="ltr">da</code></td></tr>
      <tr><td>Dutch</td><td><code translate="no" dir="ltr">nl</code></td></tr>
      <tr><td>English</td><td><code translate="no" dir="ltr">en</code></td></tr>
      <tr><td>English (United States)</td><td><code translate="no" dir="ltr">en_<wbr>us</code></td></tr>
      <tr><td>English (Australia)</td><td><code translate="no" dir="ltr">en_<wbr>au</code></td></tr>
      <tr><td>English (Canada)</td><td><code translate="no" dir="ltr">en_<wbr>ca</code></td></tr>
      <tr><td>English (United Kingdom)</td><td><code translate="no" dir="ltr">en_<wbr>gb</code></td></tr>
      <tr><td>English (Ireland)</td><td><code translate="no" dir="ltr">en_<wbr>ie</code></td></tr>
      <tr><td>English (India)</td><td><code translate="no" dir="ltr">en_<wbr>in</code></td></tr>
      <tr><td>English (Singapore)</td><td><code translate="no" dir="ltr">en_<wbr>sg</code></td></tr>
      <tr><td>English (South Africa)</td><td><code translate="no" dir="ltr">en_<wbr>za</code></td></tr>
      <tr><td>Estonian</td><td><code translate="no" dir="ltr">et</code></td></tr>
      <tr><td>Farsi</td><td><code translate="no" dir="ltr">fa</code></td></tr>
      <tr><td>Filipino</td><td><code translate="no" dir="ltr">fil</code></td></tr>
      <tr><td>Finnish</td><td><code translate="no" dir="ltr">fi</code></td></tr>
      <tr><td>French</td><td><code translate="no" dir="ltr">fr</code></td></tr>
      <tr><td>French (Canada)</td><td><code translate="no" dir="ltr">fr_<wbr>ca</code></td></tr>
      <tr><td>French (Switzerland)</td><td><code translate="no" dir="ltr">fr_<wbr>ch</code></td></tr>
      <tr><td>Galician</td><td><code translate="no" dir="ltr">gl</code></td></tr>
      <tr><td>German</td><td><code translate="no" dir="ltr">de</code></td></tr>
      <tr><td>German (Austria)</td><td><code translate="no" dir="ltr">de_<wbr>at</code></td></tr>
      <tr><td>Greek</td><td><code translate="no" dir="ltr">el</code></td></tr>
      <tr><td>Gujarati</td><td><code translate="no" dir="ltr">gu</code></td></tr>
      <tr><td>Hebrew</td><td><code translate="no" dir="ltr">he</code></td></tr>
      <tr><td>Hindi</td><td><code translate="no" dir="ltr">hi</code></td></tr>
      <tr><td>Hungarian</td><td><code translate="no" dir="ltr">hu</code></td></tr>
      <tr><td>Icelandic</td><td><code translate="no" dir="ltr">is</code></td></tr>
      <tr><td>Indonesian</td><td><code translate="no" dir="ltr">id</code></td></tr>
      <tr><td>Italian</td><td><code translate="no" dir="ltr">it</code></td></tr>
      <tr><td>Japanese</td><td><code translate="no" dir="ltr">ja</code></td></tr>
      <tr><td>Kannada</td><td><code translate="no" dir="ltr">kn</code></td></tr>
      <tr><td>Korean</td><td><code translate="no" dir="ltr">ko</code></td></tr>
      <tr><td>Lao</td><td><code translate="no" dir="ltr">lo</code></td></tr>
      <tr><td>Latvian</td><td><code translate="no" dir="ltr">lv</code></td></tr>
      <tr><td>Lingala</td><td><code translate="no" dir="ltr">ln</code></td></tr>
      <tr><td>Lithuanian</td><td><code translate="no" dir="ltr">lt</code></td></tr>
      <tr><td>Malay</td><td><code translate="no" dir="ltr">ms</code></td></tr>
      <tr><td>Malayalam</td><td><code translate="no" dir="ltr">ml</code></td></tr>
      <tr><td>Marathi</td><td><code translate="no" dir="ltr">mr</code></td></tr>
      <tr><td>Norwegian</td><td><code translate="no" dir="ltr">no</code></td></tr>
      <tr><td>Polish</td><td><code translate="no" dir="ltr">pl</code></td></tr>
      <tr><td>Portuguese</td><td><code translate="no" dir="ltr">pt</code></td></tr>
      <tr><td>Portuguese (Brazil)</td><td><code translate="no" dir="ltr">pt_<wbr>br</code></td></tr>
      <tr><td>Portuguese (Portugal)</td><td><code translate="no" dir="ltr">pt_<wbr>pt</code></td></tr>
      <tr><td>Romanian</td><td><code translate="no" dir="ltr">ro</code></td></tr>
      <tr><td>Russian</td><td><code translate="no" dir="ltr">ru</code></td></tr>
      <tr><td>Serbian</td><td><code translate="no" dir="ltr">sr</code></td></tr>
      <tr><td>Slovak</td><td><code translate="no" dir="ltr">sk</code></td></tr>
      <tr><td>Slovenian</td><td><code translate="no" dir="ltr">sl</code></td></tr>
      <tr><td>Spanish</td><td><code translate="no" dir="ltr">es</code></td></tr>
      <tr><td>Spanish (Latin America)</td><td><code translate="no" dir="ltr">es_<wbr>419</code></td></tr>
      <tr><td>Spanish (Argentina)</td><td><code translate="no" dir="ltr">es_<wbr>ar</code></td></tr>
      <tr><td>Spanish (Chile)</td><td><code translate="no" dir="ltr">es_<wbr>cl</code></td></tr>
      <tr><td>Spanish (Colombia)</td><td><code translate="no" dir="ltr">es_<wbr>co</code></td></tr>
      <tr><td>Spanish (Costa Rica)</td><td><code translate="no" dir="ltr">es_<wbr>cr</code></td></tr>
      <tr><td>Spanish (Dominican Rep.)</td><td><code translate="no" dir="ltr">es_<wbr>do</code></td></tr>
      <tr><td>Spanish (Ecuador)</td><td><code translate="no" dir="ltr">es_<wbr>ec</code></td></tr>
      <tr><td>Spanish (El Salvador)</td><td><code translate="no" dir="ltr">es_<wbr>sv</code></td></tr>
      <tr><td>Spanish (Guatemala)</td><td><code translate="no" dir="ltr">es_<wbr>gt</code></td></tr>
      <tr><td>Spanish (Honduras)</td><td><code translate="no" dir="ltr">es_<wbr>hn</code></td></tr>
      <tr><td>Spanish (Mexico)</td><td><code translate="no" dir="ltr">es_<wbr>mx</code></td></tr>
      <tr><td>Spanish (Nicaragua)</td><td><code translate="no" dir="ltr">es_<wbr>ni</code></td></tr>
      <tr><td>Spanish (Panama)</td><td><code translate="no" dir="ltr">es_<wbr>pa</code></td></tr>
      <tr><td>Spanish (Peru)</td><td><code translate="no" dir="ltr">es_<wbr>pe</code></td></tr>
      <tr><td>Spanish (Puerto Rico)</td><td><code translate="no" dir="ltr">es_<wbr>pr</code></td></tr>
      <tr><td>Spanish (Paraguay)</td><td><code translate="no" dir="ltr">es_<wbr>py</code></td></tr>
      <tr><td>Spanish (United States)</td><td><code translate="no" dir="ltr">es_<wbr>us</code></td></tr>
      <tr><td>Spanish (Uruguay)</td><td><code translate="no" dir="ltr">es_<wbr>uy</code></td></tr>
      <tr><td>Spanish (Venezuela)</td><td><code translate="no" dir="ltr">es_<wbr>ve</code></td></tr>
      <tr><td>Swahili</td><td><code translate="no" dir="ltr">sw</code></td></tr>
      <tr><td>Swedish</td><td><code translate="no" dir="ltr">sv</code></td></tr>
      <tr><td>Swiss German</td><td><code translate="no" dir="ltr">gsw</code></td></tr>
      <tr><td>Tagalog</td><td><code translate="no" dir="ltr">tl</code></td></tr>
      <tr><td>Tamil</td><td><code translate="no" dir="ltr">ta</code></td></tr>
      <tr><td>Telugu</td><td><code translate="no" dir="ltr">te</code></td></tr>
      <tr><td>Thai</td><td><code translate="no" dir="ltr">th</code></td></tr>
      <tr><td>Turkish</td><td><code translate="no" dir="ltr">tr</code></td></tr>
      <tr><td>Ukrainian</td><td><code translate="no" dir="ltr">uk</code></td></tr>
      <tr><td>Urdu</td><td><code translate="no" dir="ltr">ur</code></td></tr>
      <tr><td>Vietnamese</td><td><code translate="no" dir="ltr">vi</code></td></tr>
      <tr><td>Zulu</td><td><code translate="no" dir="ltr">zu</code></td></tr>
    </tbody>
  </table>

==> seleniumbase-1.63.19.tar.gz: seleniumbase-1.63.19/help_docs/locale_codes.md <==
<h2><img src="https://seleniumbase.io/img/logo6.png" title="SeleniumBase" width="25" /> Language Locale Codes</h2>

You can specify a Language Locale Code to customize web pages on supported websites. With SeleniumBase you can change the web browser's Locale on the command line by adding:

```bash
--locale=CODE  # Example: --locale=ru
```

<h3><img src="https://seleniumbase.io/img/logo6.png" title="SeleniumBase" width="25" /> List of Language Locale Codes:</h3>

<table>
    <thead><tr><th>Language</th><th>Code</th></tr></thead>
    <tbody class="list">
      <tr><td>Afrikaans</td><td><code translate="no" dir="ltr">af</code></td></tr>
      <tr><td>Amharic</td><td><code translate="no" dir="ltr">am</code></td></tr>
      <tr><td>Arabic</td><td><code translate="no" dir="ltr">ar</code></td></tr>
      <tr><td>Arabic (Egypt)</td><td><code translate="no" dir="ltr">ar_<wbr>eg</code></td></tr>
      <tr><td>Arabic (Saudi Arabia)</td><td><code translate="no" dir="ltr">ar_<wbr>sa</code></td></tr>
      <tr><td>Basque</td><td><code translate="no" dir="ltr">eu</code></td></tr>
      <tr><td>Belarusian</td><td><code translate="no" dir="ltr">be</code></td></tr>
      <tr><td>Bengali</td><td><code translate="no" dir="ltr">bn</code></td></tr>
      <tr><td>Bulgarian</td><td><code translate="no" dir="ltr">bg</code></td></tr>
      <tr><td>Catalan</td><td><code translate="no" dir="ltr">ca</code></td></tr>
      <tr><td>Chinese</td><td><code translate="no" dir="ltr">zh</code></td></tr>
      <tr><td>Chinese (China Mainland)</td><td><code translate="no" dir="ltr">zh_<wbr>cn</code></td></tr>
      <tr><td>Chinese (Hong Kong)</td><td><code translate="no" dir="ltr">zh_<wbr>hk</code></td></tr>
      <tr><td>Chinese (Taiwan)</td><td><code translate="no" dir="ltr">zh_<wbr>tw</code></td></tr>
      <tr><td>Croatian</td><td><code translate="no" dir="ltr">hr</code></td></tr>
      <tr><td>Czech</td><td><code translate="no" dir="ltr">cs</code></td></tr>
      <tr><td>Danish</td><td><code translate="no" dir="ltr">da</code></td></tr>
      <tr><td>Dutch</td><td><code translate="no" dir="ltr">nl</code></td></tr>
      <tr><td>English</td><td><code translate="no" dir="ltr">en</code></td></tr>
      <tr><td>English (United States)</td><td><code translate="no" dir="ltr">en_<wbr>us</code></td></tr>
      <tr><td>English (Australia)</td><td><code translate="no" dir="ltr">en_<wbr>au</code></td></tr>
      <tr><td>English (Canada)</td><td><code translate="no" dir="ltr">en_<wbr>ca</code></td></tr>
      <tr><td>English (United Kingdom)</td><td><code translate="no" dir="ltr">en_<wbr>gb</code></td></tr>
      <tr><td>English (Ireland)</td><td><code translate="no" dir="ltr">en_<wbr>ie</code></td></tr>
      <tr><td>English (India)</td><td><code translate="no" dir="ltr">en_<wbr>in</code></td></tr>
      <tr><td>English (Singapore)</td><td><code translate="no" dir="ltr">en_<wbr>sg</code></td></tr>
      <tr><td>English (South Africa)</td><td><code translate="no" dir="ltr">en_<wbr>za</code></td></tr>
      <tr><td>Estonian</td><td><code translate="no" dir="ltr">et</code></td></tr>
      <tr><td>Farsi</td><td><code translate="no" dir="ltr">fa</code></td></tr>
      <tr><td>Filipino</td><td><code translate="no" dir="ltr">fil</code></td></tr>
      <tr><td>Finnish</td><td><code translate="no" dir="ltr">fi</code></td></tr>
      <tr><td>French</td><td><code translate="no" dir="ltr">fr</code></td></tr>
      <tr><td>French (Canada)</td><td><code translate="no" dir="ltr">fr_<wbr>ca</code></td></tr>
      <tr><td>French (Switzerland)</td><td><code translate="no" dir="ltr">fr_<wbr>ch</code></td></tr>
      <tr><td>Galician</td><td><code translate="no" dir="ltr">gl</code></td></tr>
      <tr><td>German</td><td><code translate="no" dir="ltr">de</code></td></tr>
      <tr><td>German (Austria)</td><td><code translate="no" dir="ltr">de_<wbr>at</code></td></tr>
      <tr><td>Greek</td><td><code translate="no" dir="ltr">el</code></td></tr>
      <tr><td>Gujarati</td><td><code translate="no" dir="ltr">gu</code></td></tr>
      <tr><td>Hebrew</td><td><code translate="no" dir="ltr">he</code></td></tr>
      <tr><td>Hindi</td><td><code translate="no" dir="ltr">hi</code></td></tr>
      <tr><td>Hungarian</td><td><code translate="no" dir="ltr">hu</code></td></tr>
      <tr><td>Icelandic</td><td><code translate="no" dir="ltr">is</code></td></tr>
      <tr><td>Indonesian</td><td><code translate="no" dir="ltr">id</code></td></tr>
      <tr><td>Italian</td><td><code translate="no" dir="ltr">it</code></td></tr>
      <tr><td>Japanese</td><td><code translate="no" dir="ltr">ja</code></td></tr>
      <tr><td>Kannada</td><td><code translate="no" dir="ltr">kn</code></td></tr>
      <tr><td>Korean</td><td><code translate="no" dir="ltr">ko</code></td></tr>
      <tr><td>Lao</td><td><code translate="no" dir="ltr">lo</code></td></tr>
      <tr><td>Latvian</td><td><code translate="no" dir="ltr">lv</code></td></tr>
      <tr><td>Lingala</td><td><code translate="no" dir="ltr">ln</code></td></tr>
      <tr><td>Lithuanian</td><td><code translate="no" dir="ltr">lt</code></td></tr>
      <tr><td>Malay</td><td><code translate="no" dir="ltr">ms</code></td></tr>
      <tr><td>Malayalam</td><td><code translate="no" dir="ltr">ml</code></td></tr>
      <tr><td>Marathi</td><td><code translate="no" dir="ltr">mr</code></td></tr>
      <tr><td>Norwegian</td><td><code translate="no" dir="ltr">no</code></td></tr>
      <tr><td>Polish</td><td><code translate="no" dir="ltr">pl</code></td></tr>
      <tr><td>Portuguese</td><td><code translate="no" dir="ltr">pt</code></td></tr>
      <tr><td>Portuguese (Brazil)</td><td><code translate="no" dir="ltr">pt_<wbr>br</code></td></tr>
      <tr><td>Portuguese (Portugal)</td><td><code translate="no" dir="ltr">pt_<wbr>pt</code></td></tr>
      <tr><td>Romanian</td><td><code translate="no" dir="ltr">ro</code></td></tr>
      <tr><td>Russian</td><td><code translate="no" dir="ltr">ru</code></td></tr>
      <tr><td>Serbian</td><td><code translate="no" dir="ltr">sr</code></td></tr>
      <tr><td>Slovak</td><td><code translate="no" dir="ltr">sk</code></td></tr>
      <tr><td>Slovenian</td><td><code translate="no" dir="ltr">sl</code></td></tr>
      <tr><td>Spanish</td><td><code translate="no" dir="ltr">es</code></td></tr>
      <tr><td>Spanish (Latin America)</td><td><code translate="no" dir="ltr">es_<wbr>419</code></td></tr>
      <tr><td>Spanish (Argentina)</td><td><code translate="no" dir="ltr">es_<wbr>ar</code></td></tr>
      <tr><td>Spanish (Chile)</td><td><code translate="no" dir="ltr">es_<wbr>cl</code></td></tr>
      <tr><td>Spanish (Colombia)</td><td><code translate="no" dir="ltr">es_<wbr>co</code></td></tr>
      <tr><td>Spanish (Costa Rica)</td><td><code translate="no" dir="ltr">es_<wbr>cr</code></td></tr>
      <tr><td>Spanish (Dominican Rep.)</td><td><code translate="no" dir="ltr">es_<wbr>do</code></td></tr>
      <tr><td>Spanish (Ecuador)</td><td><code translate="no" dir="ltr">es_<wbr>ec</code></td></tr>
      <tr><td>Spanish (El Salvador)</td><td><code translate="no" dir="ltr">es_<wbr>sv</code></td></tr>
      <tr><td>Spanish (Guatemala)</td><td><code translate="no" dir="ltr">es_<wbr>gt</code></td></tr>
      <tr><td>Spanish (Honduras)</td><td><code translate="no" dir="ltr">es_<wbr>hn</code></td></tr>
      <tr><td>Spanish (Mexico)</td><td><code translate="no" dir="ltr">es_<wbr>mx</code></td></tr>
      <tr><td>Spanish (Nicaragua)</td><td><code translate="no" dir="ltr">es_<wbr>ni</code></td></tr>
      <tr><td>Spanish (Panama)</td><td><code translate="no" dir="ltr">es_<wbr>pa</code></td></tr>
      <tr><td>Spanish (Peru)</td><td><code translate="no" dir="ltr">es_<wbr>pe</code></td></tr>
      <tr><td>Spanish (Puerto Rico)</td><td><code translate="no" dir="ltr">es_<wbr>pr</code></td></tr>
      <tr><td>Spanish (Paraguay)</td><td><code translate="no" dir="ltr">es_<wbr>py</code></td></tr>
      <tr><td>Spanish (United States)</td><td><code translate="no" dir="ltr">es_<wbr>us</code></td></tr>
      <tr><td>Spanish (Uruguay)</td><td><code translate="no" dir="ltr">es_<wbr>uy</code></td></tr>
      <tr><td>Spanish (Venezuela)</td><td><code translate="no" dir="ltr">es_<wbr>ve</code></td></tr>
      <tr><td>Swahili</td><td><code translate="no" dir="ltr">sw</code></td></tr>
      <tr><td>Swedish</td><td><code translate="no" dir="ltr">sv</code></td></tr>
      <tr><td>Swiss German</td><td><code translate="no" dir="ltr">gsw</code></td></tr>
      <tr><td>Tagalog</td><td><code translate="no" dir="ltr">tl</code></td></tr>
      <tr><td>Tamil</td><td><code translate="no" dir="ltr">ta</code></td></tr>
      <tr><td>Telugu</td><td><code translate="no" dir="ltr">te</code></td></tr>
      <tr><td>Thai</td><td><code translate="no" dir="ltr">th</code></td></tr>
      <tr><td>Turkish</td><td><code translate="no" dir="ltr">tr</code></td></tr>
      <tr><td>Ukrainian</td><td><code translate="no" dir="ltr">uk</code></td></tr>
      <tr><td>Urdu</td><td><code translate="no" dir="ltr">ur</code></td></tr>
      <tr><td>Vietnamese</td><td><code translate="no" dir="ltr">vi</code></td></tr>
      <tr><td>Zulu</td><td><code translate="no" dir="ltr">zu</code></td></tr>
    </tbody>
  </table>
